# Roboto SDK
This package contains the official toolkit for interacting with [Roboto AI](https://www.roboto.ai/).
It consists of the `roboto_sdk` module, as well as a `roboto` command line utility.

For more information, check out:
* [High Level Documentation](https://docs.roboto.ai/)
* [SDK Reference for This Module](https://docs.roboto.ai/reference/python-sdk.html)
* [CLI Reference](https://docs.roboto.ai/reference/cli.html)
* [About Roboto](https://www.roboto.ai/about)